physics property
The scroll physics that determine the spring behavior when pulling or releasing the indicator for refresh.
Implementation
final ScrollPhysics? physics;
The scroll physics that determine the spring behavior when pulling or releasing the indicator for refresh.
final ScrollPhysics? physics;