flutter_refresh_indicator library
Classes
- BouncingRefreshIndicator
- ClampingRefreshIndicator
- PrimaryRefreshIndicator
- A inherited widget globally provides the style information for refresh indicators to all descendant widgets in the widget tree.
- RefreshIndicator
- A widget that supports the Material "swipe to refresh" idiom.
Enums
- BouncingRefreshIndicatorStatus
- Signature for the current status of a BouncingRefreshIndicator. Indicates whether the indicator is idle, loading, or loaded.
- ClampingRefreshIndicatorStatus
- Signature for the current status of a ClampingRefreshIndicator. Indicates whether the indicator is idle, being pulled, or loading.
- RefreshIndicatorType
Typedefs
- BouncingRefreshIndicatorBuilder = Widget Function(BouncingRefreshIndicatorStatus status, double fraction, bool isActive, bool isActivable)
- Signature for a builder function that creates a widget for a BouncingRefreshIndicator based on the current refresh status.
- ClampingRefreshIndicatorBuilder = Widget Function(ClampingRefreshIndicatorStatus status, double fraction, double fadeFraction, bool isActivable)
- Signature for a builder function that creates a widget for a ClampingRefreshIndicator based on the current refresh status.
- PullToRefresh = RefreshIndicator
- Signature for the alias that is representing of the RefreshIndicator widget.
- SwipeToRefresh = RefreshIndicator
- Signature for the alias that is representing of the RefreshIndicator widget.