widgets/refresh_indicator library
Classes
- RefreshIndicator
- A widget that supports the Material "swipe to refresh" idiom.
Enums
- RefreshIndicatorType
- Defines the visual and behavioral style of the refresh indicator.
Typedefs
- PullToRefresh = RefreshIndicator
- Signature for the alias that is representing of the RefreshIndicator widget.
- SwipeToRefresh = RefreshIndicator
- Signature for the alias that is representing of the RefreshIndicator widget.